# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunTestRunConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'run_name': 'str',
        'model_id': 'RimeUUID',
        'data_info': 'TestrunRefEvalDatasets',
        'run_time_info': 'RuntimeinfoRunTimeInfo',
        'profiling_config': 'TestrunProfilingConfig',
        'test_suite_config': 'TestrunTestSuiteConfig',
        'categories': 'list[TestrunTestCategoryType]',
        'language': 'RimeLanguage'
    }

    attribute_map = {
        'run_name': 'runName',
        'model_id': 'modelId',
        'data_info': 'dataInfo',
        'run_time_info': 'runTimeInfo',
        'profiling_config': 'profilingConfig',
        'test_suite_config': 'testSuiteConfig',
        'categories': 'categories',
        'language': 'language'
    }

    def __init__(self, run_name=None, model_id=None, data_info=None, run_time_info=None, profiling_config=None, test_suite_config=None, categories=None, language=None):  # noqa: E501
        """TestrunTestRunConfig - a model defined in Swagger"""  # noqa: E501
        self._run_name = None
        self._model_id = None
        self._data_info = None
        self._run_time_info = None
        self._profiling_config = None
        self._test_suite_config = None
        self._categories = None
        self._language = None
        self.discriminator = None
        self.run_name = run_name
        self.model_id = model_id
        self.data_info = data_info
        if run_time_info is not None:
            self.run_time_info = run_time_info
        if profiling_config is not None:
            self.profiling_config = profiling_config
        if test_suite_config is not None:
            self.test_suite_config = test_suite_config
        if categories is not None:
            self.categories = categories
        if language is not None:
            self.language = language

    @property
    def run_name(self):
        """Gets the run_name of this TestrunTestRunConfig.  # noqa: E501

        Name for this Test Run.  # noqa: E501

        :return: The run_name of this TestrunTestRunConfig.  # noqa: E501
        :rtype: str
        """
        return self._run_name

    @run_name.setter
    def run_name(self, run_name):
        """Sets the run_name of this TestrunTestRunConfig.

        Name for this Test Run.  # noqa: E501

        :param run_name: The run_name of this TestrunTestRunConfig.  # noqa: E501
        :type: str
        """
        if run_name is None:
            raise ValueError("Invalid value for `run_name`, must not be `None`")  # noqa: E501

        self._run_name = run_name

    @property
    def model_id(self):
        """Gets the model_id of this TestrunTestRunConfig.  # noqa: E501


        :return: The model_id of this TestrunTestRunConfig.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this TestrunTestRunConfig.


        :param model_id: The model_id of this TestrunTestRunConfig.  # noqa: E501
        :type: RimeUUID
        """
        if model_id is None:
            raise ValueError("Invalid value for `model_id`, must not be `None`")  # noqa: E501

        self._model_id = model_id

    @property
    def data_info(self):
        """Gets the data_info of this TestrunTestRunConfig.  # noqa: E501


        :return: The data_info of this TestrunTestRunConfig.  # noqa: E501
        :rtype: TestrunRefEvalDatasets
        """
        return self._data_info

    @data_info.setter
    def data_info(self, data_info):
        """Sets the data_info of this TestrunTestRunConfig.


        :param data_info: The data_info of this TestrunTestRunConfig.  # noqa: E501
        :type: TestrunRefEvalDatasets
        """
        if data_info is None:
            raise ValueError("Invalid value for `data_info`, must not be `None`")  # noqa: E501

        self._data_info = data_info

    @property
    def run_time_info(self):
        """Gets the run_time_info of this TestrunTestRunConfig.  # noqa: E501


        :return: The run_time_info of this TestrunTestRunConfig.  # noqa: E501
        :rtype: RuntimeinfoRunTimeInfo
        """
        return self._run_time_info

    @run_time_info.setter
    def run_time_info(self, run_time_info):
        """Sets the run_time_info of this TestrunTestRunConfig.


        :param run_time_info: The run_time_info of this TestrunTestRunConfig.  # noqa: E501
        :type: RuntimeinfoRunTimeInfo
        """

        self._run_time_info = run_time_info

    @property
    def profiling_config(self):
        """Gets the profiling_config of this TestrunTestRunConfig.  # noqa: E501


        :return: The profiling_config of this TestrunTestRunConfig.  # noqa: E501
        :rtype: TestrunProfilingConfig
        """
        return self._profiling_config

    @profiling_config.setter
    def profiling_config(self, profiling_config):
        """Sets the profiling_config of this TestrunTestRunConfig.


        :param profiling_config: The profiling_config of this TestrunTestRunConfig.  # noqa: E501
        :type: TestrunProfilingConfig
        """

        self._profiling_config = profiling_config

    @property
    def test_suite_config(self):
        """Gets the test_suite_config of this TestrunTestRunConfig.  # noqa: E501


        :return: The test_suite_config of this TestrunTestRunConfig.  # noqa: E501
        :rtype: TestrunTestSuiteConfig
        """
        return self._test_suite_config

    @test_suite_config.setter
    def test_suite_config(self, test_suite_config):
        """Sets the test_suite_config of this TestrunTestRunConfig.


        :param test_suite_config: The test_suite_config of this TestrunTestRunConfig.  # noqa: E501
        :type: TestrunTestSuiteConfig
        """

        self._test_suite_config = test_suite_config

    @property
    def categories(self):
        """Gets the categories of this TestrunTestRunConfig.  # noqa: E501

        List of test categories to be run.  # noqa: E501

        :return: The categories of this TestrunTestRunConfig.  # noqa: E501
        :rtype: list[TestrunTestCategoryType]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this TestrunTestRunConfig.

        List of test categories to be run.  # noqa: E501

        :param categories: The categories of this TestrunTestRunConfig.  # noqa: E501
        :type: list[TestrunTestCategoryType]
        """

        self._categories = categories

    @property
    def language(self):
        """Gets the language of this TestrunTestRunConfig.  # noqa: E501


        :return: The language of this TestrunTestRunConfig.  # noqa: E501
        :rtype: RimeLanguage
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this TestrunTestRunConfig.


        :param language: The language of this TestrunTestRunConfig.  # noqa: E501
        :type: RimeLanguage
        """

        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunTestRunConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunTestRunConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class V1firewallfirewallFirewallIdUuidFirewall(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'object',
        'project_id': 'RimeUUID',
        'model_id': 'RimeUUID',
        'bin_size': 'str',
        'ref_data_id': 'str',
        'scheduled_ct_info': 'FirewallScheduledCTInfo',
        'risk_scores': 'list[RiskscoreRiskScore]',
        'test_category_severities': 'list[FirewallTestCategorySeverity]',
        'latest_run_info': 'FirewallLatestRunInfo'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'project_id': 'projectId',
        'model_id': 'modelId',
        'bin_size': 'binSize',
        'ref_data_id': 'refDataId',
        'scheduled_ct_info': 'scheduledCtInfo',
        'risk_scores': 'riskScores',
        'test_category_severities': 'testCategorySeverities',
        'latest_run_info': 'latestRunInfo'
    }

    def __init__(self, firewall_id=None, project_id=None, model_id=None, bin_size=None, ref_data_id=None, scheduled_ct_info=None, risk_scores=None, test_category_severities=None, latest_run_info=None):  # noqa: E501
        """V1firewallfirewallFirewallIdUuidFirewall - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._project_id = None
        self._model_id = None
        self._bin_size = None
        self._ref_data_id = None
        self._scheduled_ct_info = None
        self._risk_scores = None
        self._test_category_severities = None
        self._latest_run_info = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if project_id is not None:
            self.project_id = project_id
        if model_id is not None:
            self.model_id = model_id
        if bin_size is not None:
            self.bin_size = bin_size
        if ref_data_id is not None:
            self.ref_data_id = ref_data_id
        if scheduled_ct_info is not None:
            self.scheduled_ct_info = scheduled_ct_info
        if risk_scores is not None:
            self.risk_scores = risk_scores
        if test_category_severities is not None:
            self.test_category_severities = test_category_severities
        if latest_run_info is not None:
            self.latest_run_info = latest_run_info

    @property
    def firewall_id(self):
        """Gets the firewall_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501

        Unique ID of an object in RIME.  # noqa: E501

        :return: The firewall_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: object
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this V1firewallfirewallFirewallIdUuidFirewall.

        Unique ID of an object in RIME.  # noqa: E501

        :param firewall_id: The firewall_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: object
        """

        self._firewall_id = firewall_id

    @property
    def project_id(self):
        """Gets the project_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The project_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this V1firewallfirewallFirewallIdUuidFirewall.


        :param project_id: The project_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: RimeUUID
        """

        self._project_id = project_id

    @property
    def model_id(self):
        """Gets the model_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The model_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this V1firewallfirewallFirewallIdUuidFirewall.


        :param model_id: The model_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: RimeUUID
        """

        self._model_id = model_id

    @property
    def bin_size(self):
        """Gets the bin_size of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The bin_size of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: str
        """
        return self._bin_size

    @bin_size.setter
    def bin_size(self, bin_size):
        """Sets the bin_size of this V1firewallfirewallFirewallIdUuidFirewall.


        :param bin_size: The bin_size of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: str
        """

        self._bin_size = bin_size

    @property
    def ref_data_id(self):
        """Gets the ref_data_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501

        The semantic ID of the reference dataset. This should correspond with the primary key in the Dataset Registry.  # noqa: E501

        :return: The ref_data_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: str
        """
        return self._ref_data_id

    @ref_data_id.setter
    def ref_data_id(self, ref_data_id):
        """Sets the ref_data_id of this V1firewallfirewallFirewallIdUuidFirewall.

        The semantic ID of the reference dataset. This should correspond with the primary key in the Dataset Registry.  # noqa: E501

        :param ref_data_id: The ref_data_id of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: str
        """

        self._ref_data_id = ref_data_id

    @property
    def scheduled_ct_info(self):
        """Gets the scheduled_ct_info of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The scheduled_ct_info of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: FirewallScheduledCTInfo
        """
        return self._scheduled_ct_info

    @scheduled_ct_info.setter
    def scheduled_ct_info(self, scheduled_ct_info):
        """Sets the scheduled_ct_info of this V1firewallfirewallFirewallIdUuidFirewall.


        :param scheduled_ct_info: The scheduled_ct_info of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: FirewallScheduledCTInfo
        """

        self._scheduled_ct_info = scheduled_ct_info

    @property
    def risk_scores(self):
        """Gets the risk_scores of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The risk_scores of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: list[RiskscoreRiskScore]
        """
        return self._risk_scores

    @risk_scores.setter
    def risk_scores(self, risk_scores):
        """Sets the risk_scores of this V1firewallfirewallFirewallIdUuidFirewall.


        :param risk_scores: The risk_scores of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: list[RiskscoreRiskScore]
        """

        self._risk_scores = risk_scores

    @property
    def test_category_severities(self):
        """Gets the test_category_severities of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The test_category_severities of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: list[FirewallTestCategorySeverity]
        """
        return self._test_category_severities

    @test_category_severities.setter
    def test_category_severities(self, test_category_severities):
        """Sets the test_category_severities of this V1firewallfirewallFirewallIdUuidFirewall.


        :param test_category_severities: The test_category_severities of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: list[FirewallTestCategorySeverity]
        """

        self._test_category_severities = test_category_severities

    @property
    def latest_run_info(self):
        """Gets the latest_run_info of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501


        :return: The latest_run_info of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :rtype: FirewallLatestRunInfo
        """
        return self._latest_run_info

    @latest_run_info.setter
    def latest_run_info(self, latest_run_info):
        """Sets the latest_run_info of this V1firewallfirewallFirewallIdUuidFirewall.


        :param latest_run_info: The latest_run_info of this V1firewallfirewallFirewallIdUuidFirewall.  # noqa: E501
        :type: FirewallLatestRunInfo
        """

        self._latest_run_info = latest_run_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1firewallfirewallFirewallIdUuidFirewall, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1firewallfirewallFirewallIdUuidFirewall):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeCreateAgentRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'local_config': 'CreateAgentRequestLocalConfig',
        'aws_config': 'CreateAgentRequestAWSConfig',
        'gcp_config': 'CreateAgentRequestGCPConfig',
        'azure_config': 'CreateAgentRequestAzureConfig'
    }

    attribute_map = {
        'name': 'name',
        'local_config': 'localConfig',
        'aws_config': 'awsConfig',
        'gcp_config': 'gcpConfig',
        'azure_config': 'azureConfig'
    }

    def __init__(self, name=None, local_config=None, aws_config=None, gcp_config=None, azure_config=None):  # noqa: E501
        """RimeCreateAgentRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._local_config = None
        self._aws_config = None
        self._gcp_config = None
        self._azure_config = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if local_config is not None:
            self.local_config = local_config
        if aws_config is not None:
            self.aws_config = aws_config
        if gcp_config is not None:
            self.gcp_config = gcp_config
        if azure_config is not None:
            self.azure_config = azure_config

    @property
    def name(self):
        """Gets the name of this RimeCreateAgentRequest.  # noqa: E501

        Agent name given by the user.  # noqa: E501

        :return: The name of this RimeCreateAgentRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RimeCreateAgentRequest.

        Agent name given by the user.  # noqa: E501

        :param name: The name of this RimeCreateAgentRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def local_config(self):
        """Gets the local_config of this RimeCreateAgentRequest.  # noqa: E501


        :return: The local_config of this RimeCreateAgentRequest.  # noqa: E501
        :rtype: CreateAgentRequestLocalConfig
        """
        return self._local_config

    @local_config.setter
    def local_config(self, local_config):
        """Sets the local_config of this RimeCreateAgentRequest.


        :param local_config: The local_config of this RimeCreateAgentRequest.  # noqa: E501
        :type: CreateAgentRequestLocalConfig
        """

        self._local_config = local_config

    @property
    def aws_config(self):
        """Gets the aws_config of this RimeCreateAgentRequest.  # noqa: E501


        :return: The aws_config of this RimeCreateAgentRequest.  # noqa: E501
        :rtype: CreateAgentRequestAWSConfig
        """
        return self._aws_config

    @aws_config.setter
    def aws_config(self, aws_config):
        """Sets the aws_config of this RimeCreateAgentRequest.


        :param aws_config: The aws_config of this RimeCreateAgentRequest.  # noqa: E501
        :type: CreateAgentRequestAWSConfig
        """

        self._aws_config = aws_config

    @property
    def gcp_config(self):
        """Gets the gcp_config of this RimeCreateAgentRequest.  # noqa: E501


        :return: The gcp_config of this RimeCreateAgentRequest.  # noqa: E501
        :rtype: CreateAgentRequestGCPConfig
        """
        return self._gcp_config

    @gcp_config.setter
    def gcp_config(self, gcp_config):
        """Sets the gcp_config of this RimeCreateAgentRequest.


        :param gcp_config: The gcp_config of this RimeCreateAgentRequest.  # noqa: E501
        :type: CreateAgentRequestGCPConfig
        """

        self._gcp_config = gcp_config

    @property
    def azure_config(self):
        """Gets the azure_config of this RimeCreateAgentRequest.  # noqa: E501


        :return: The azure_config of this RimeCreateAgentRequest.  # noqa: E501
        :rtype: CreateAgentRequestAzureConfig
        """
        return self._azure_config

    @azure_config.setter
    def azure_config(self, azure_config):
        """Sets the azure_config of this RimeCreateAgentRequest.


        :param azure_config: The azure_config of this RimeCreateAgentRequest.  # noqa: E501
        :type: CreateAgentRequestAzureConfig
        """

        self._azure_config = azure_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeCreateAgentRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeCreateAgentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryDataLoadingInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'str',
        'load_func_name': 'str',
        'loader_kwargs_json': 'str',
        'data_endpoint_integration_id': 'RimeUUID'
    }

    attribute_map = {
        'path': 'path',
        'load_func_name': 'loadFuncName',
        'loader_kwargs_json': 'loaderKwargsJson',
        'data_endpoint_integration_id': 'dataEndpointIntegrationId'
    }

    def __init__(self, path=None, load_func_name=None, loader_kwargs_json=None, data_endpoint_integration_id=None):  # noqa: E501
        """RegistryDataLoadingInfo - a model defined in Swagger"""  # noqa: E501
        self._path = None
        self._load_func_name = None
        self._loader_kwargs_json = None
        self._data_endpoint_integration_id = None
        self.discriminator = None
        self.path = path
        self.load_func_name = load_func_name
        if loader_kwargs_json is not None:
            self.loader_kwargs_json = loader_kwargs_json
        if data_endpoint_integration_id is not None:
            self.data_endpoint_integration_id = data_endpoint_integration_id

    @property
    def path(self):
        """Gets the path of this RegistryDataLoadingInfo.  # noqa: E501

        The path to the python file containing the data loading function.  # noqa: E501

        :return: The path of this RegistryDataLoadingInfo.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this RegistryDataLoadingInfo.

        The path to the python file containing the data loading function.  # noqa: E501

        :param path: The path of this RegistryDataLoadingInfo.  # noqa: E501
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def load_func_name(self):
        """Gets the load_func_name of this RegistryDataLoadingInfo.  # noqa: E501

        The name of the function that loads the data.  # noqa: E501

        :return: The load_func_name of this RegistryDataLoadingInfo.  # noqa: E501
        :rtype: str
        """
        return self._load_func_name

    @load_func_name.setter
    def load_func_name(self, load_func_name):
        """Sets the load_func_name of this RegistryDataLoadingInfo.

        The name of the function that loads the data.  # noqa: E501

        :param load_func_name: The load_func_name of this RegistryDataLoadingInfo.  # noqa: E501
        :type: str
        """
        if load_func_name is None:
            raise ValueError("Invalid value for `load_func_name`, must not be `None`")  # noqa: E501

        self._load_func_name = load_func_name

    @property
    def loader_kwargs_json(self):
        """Gets the loader_kwargs_json of this RegistryDataLoadingInfo.  # noqa: E501

        This is a JSON-serialized string from a map.  # noqa: E501

        :return: The loader_kwargs_json of this RegistryDataLoadingInfo.  # noqa: E501
        :rtype: str
        """
        return self._loader_kwargs_json

    @loader_kwargs_json.setter
    def loader_kwargs_json(self, loader_kwargs_json):
        """Sets the loader_kwargs_json of this RegistryDataLoadingInfo.

        This is a JSON-serialized string from a map.  # noqa: E501

        :param loader_kwargs_json: The loader_kwargs_json of this RegistryDataLoadingInfo.  # noqa: E501
        :type: str
        """

        self._loader_kwargs_json = loader_kwargs_json

    @property
    def data_endpoint_integration_id(self):
        """Gets the data_endpoint_integration_id of this RegistryDataLoadingInfo.  # noqa: E501


        :return: The data_endpoint_integration_id of this RegistryDataLoadingInfo.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._data_endpoint_integration_id

    @data_endpoint_integration_id.setter
    def data_endpoint_integration_id(self, data_endpoint_integration_id):
        """Sets the data_endpoint_integration_id of this RegistryDataLoadingInfo.


        :param data_endpoint_integration_id: The data_endpoint_integration_id of this RegistryDataLoadingInfo.  # noqa: E501
        :type: RimeUUID
        """

        self._data_endpoint_integration_id = data_endpoint_integration_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryDataLoadingInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryDataLoadingInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ListMonitorsRequestFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'included_monitor_types': 'list[MonitorMonitorType]',
        'included_risk_category_types': 'list[RiskscoreRiskCategoryType]',
        'pinned_monitors_only': 'bool'
    }

    attribute_map = {
        'included_monitor_types': 'includedMonitorTypes',
        'included_risk_category_types': 'includedRiskCategoryTypes',
        'pinned_monitors_only': 'pinnedMonitorsOnly'
    }

    def __init__(self, included_monitor_types=None, included_risk_category_types=None, pinned_monitors_only=None):  # noqa: E501
        """ListMonitorsRequestFilter - a model defined in Swagger"""  # noqa: E501
        self._included_monitor_types = None
        self._included_risk_category_types = None
        self._pinned_monitors_only = None
        self.discriminator = None
        if included_monitor_types is not None:
            self.included_monitor_types = included_monitor_types
        if included_risk_category_types is not None:
            self.included_risk_category_types = included_risk_category_types
        if pinned_monitors_only is not None:
            self.pinned_monitors_only = pinned_monitors_only

    @property
    def included_monitor_types(self):
        """Gets the included_monitor_types of this ListMonitorsRequestFilter.  # noqa: E501

        Specifies a list of monitor types. Filters results to match the specified monitor types.  # noqa: E501

        :return: The included_monitor_types of this ListMonitorsRequestFilter.  # noqa: E501
        :rtype: list[MonitorMonitorType]
        """
        return self._included_monitor_types

    @included_monitor_types.setter
    def included_monitor_types(self, included_monitor_types):
        """Sets the included_monitor_types of this ListMonitorsRequestFilter.

        Specifies a list of monitor types. Filters results to match the specified monitor types.  # noqa: E501

        :param included_monitor_types: The included_monitor_types of this ListMonitorsRequestFilter.  # noqa: E501
        :type: list[MonitorMonitorType]
        """

        self._included_monitor_types = included_monitor_types

    @property
    def included_risk_category_types(self):
        """Gets the included_risk_category_types of this ListMonitorsRequestFilter.  # noqa: E501

        Specifies a list of risk category types. Filters results to match the specified risk category types.  # noqa: E501

        :return: The included_risk_category_types of this ListMonitorsRequestFilter.  # noqa: E501
        :rtype: list[RiskscoreRiskCategoryType]
        """
        return self._included_risk_category_types

    @included_risk_category_types.setter
    def included_risk_category_types(self, included_risk_category_types):
        """Sets the included_risk_category_types of this ListMonitorsRequestFilter.

        Specifies a list of risk category types. Filters results to match the specified risk category types.  # noqa: E501

        :param included_risk_category_types: The included_risk_category_types of this ListMonitorsRequestFilter.  # noqa: E501
        :type: list[RiskscoreRiskCategoryType]
        """

        self._included_risk_category_types = included_risk_category_types

    @property
    def pinned_monitors_only(self):
        """Gets the pinned_monitors_only of this ListMonitorsRequestFilter.  # noqa: E501

        When the value of this Boolean is True, this endpoint returns a list of pinned Monitors. Otherwise, this endpoint does not filter Monitors by pinned status.  # noqa: E501

        :return: The pinned_monitors_only of this ListMonitorsRequestFilter.  # noqa: E501
        :rtype: bool
        """
        return self._pinned_monitors_only

    @pinned_monitors_only.setter
    def pinned_monitors_only(self, pinned_monitors_only):
        """Sets the pinned_monitors_only of this ListMonitorsRequestFilter.

        When the value of this Boolean is True, this endpoint returns a list of pinned Monitors. Otherwise, this endpoint does not filter Monitors by pinned status.  # noqa: E501

        :param pinned_monitors_only: The pinned_monitors_only of this ListMonitorsRequestFilter.  # noqa: E501
        :type: bool
        """

        self._pinned_monitors_only = pinned_monitors_only

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListMonitorsRequestFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListMonitorsRequestFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallOffTopicRuleConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'in_domain_intents': 'list[str]',
        'restricted_intents': 'list[str]',
        'in_domain_intents_sensitivity': 'GenerativefirewallRuleSensitivity',
        'restricted_intents_sensitivity': 'GenerativefirewallRuleSensitivity',
        'experimental_fields': 'dict(str, object)'
    }

    attribute_map = {
        'in_domain_intents': 'inDomainIntents',
        'restricted_intents': 'restrictedIntents',
        'in_domain_intents_sensitivity': 'inDomainIntentsSensitivity',
        'restricted_intents_sensitivity': 'restrictedIntentsSensitivity',
        'experimental_fields': 'experimentalFields'
    }

    def __init__(self, in_domain_intents=None, restricted_intents=None, in_domain_intents_sensitivity=None, restricted_intents_sensitivity=None, experimental_fields=None):  # noqa: E501
        """GenerativefirewallOffTopicRuleConfig - a model defined in Swagger"""  # noqa: E501
        self._in_domain_intents = None
        self._restricted_intents = None
        self._in_domain_intents_sensitivity = None
        self._restricted_intents_sensitivity = None
        self._experimental_fields = None
        self.discriminator = None
        if in_domain_intents is not None:
            self.in_domain_intents = in_domain_intents
        if restricted_intents is not None:
            self.restricted_intents = restricted_intents
        if in_domain_intents_sensitivity is not None:
            self.in_domain_intents_sensitivity = in_domain_intents_sensitivity
        if restricted_intents_sensitivity is not None:
            self.restricted_intents_sensitivity = restricted_intents_sensitivity
        if experimental_fields is not None:
            self.experimental_fields = experimental_fields

    @property
    def in_domain_intents(self):
        """Gets the in_domain_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501

        In_domain_intents is a list of strings that are considered on-topic. Total number of data points in in_domain_intents and restricted_intents should not exceed 500 and total bytes should not exceed 300KB.  # noqa: E501

        :return: The in_domain_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: list[str]
        """
        return self._in_domain_intents

    @in_domain_intents.setter
    def in_domain_intents(self, in_domain_intents):
        """Sets the in_domain_intents of this GenerativefirewallOffTopicRuleConfig.

        In_domain_intents is a list of strings that are considered on-topic. Total number of data points in in_domain_intents and restricted_intents should not exceed 500 and total bytes should not exceed 300KB.  # noqa: E501

        :param in_domain_intents: The in_domain_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: list[str]
        """

        self._in_domain_intents = in_domain_intents

    @property
    def restricted_intents(self):
        """Gets the restricted_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501


        :return: The restricted_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: list[str]
        """
        return self._restricted_intents

    @restricted_intents.setter
    def restricted_intents(self, restricted_intents):
        """Sets the restricted_intents of this GenerativefirewallOffTopicRuleConfig.


        :param restricted_intents: The restricted_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: list[str]
        """

        self._restricted_intents = restricted_intents

    @property
    def in_domain_intents_sensitivity(self):
        """Gets the in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501


        :return: The in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: GenerativefirewallRuleSensitivity
        """
        return self._in_domain_intents_sensitivity

    @in_domain_intents_sensitivity.setter
    def in_domain_intents_sensitivity(self, in_domain_intents_sensitivity):
        """Sets the in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.


        :param in_domain_intents_sensitivity: The in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: GenerativefirewallRuleSensitivity
        """

        self._in_domain_intents_sensitivity = in_domain_intents_sensitivity

    @property
    def restricted_intents_sensitivity(self):
        """Gets the restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501


        :return: The restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: GenerativefirewallRuleSensitivity
        """
        return self._restricted_intents_sensitivity

    @restricted_intents_sensitivity.setter
    def restricted_intents_sensitivity(self, restricted_intents_sensitivity):
        """Sets the restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.


        :param restricted_intents_sensitivity: The restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: GenerativefirewallRuleSensitivity
        """

        self._restricted_intents_sensitivity = restricted_intents_sensitivity

    @property
    def experimental_fields(self):
        """Gets the experimental_fields of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501

        experimental_fields are fields that are experimental in off topic.  # noqa: E501

        :return: The experimental_fields of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._experimental_fields

    @experimental_fields.setter
    def experimental_fields(self, experimental_fields):
        """Sets the experimental_fields of this GenerativefirewallOffTopicRuleConfig.

        experimental_fields are fields that are experimental in off topic.  # noqa: E501

        :param experimental_fields: The experimental_fields of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: dict(str, object)
        """

        self._experimental_fields = experimental_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallOffTopicRuleConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallOffTopicRuleConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SchemafilescanningFileScanResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_scan_id': 'RimeUUID',
        'project_id': 'RimeUUID',
        'model_id': 'RimeUUID',
        'rime_agent_version': 'str',
        'upload_time': 'datetime',
        'file_security_reports': 'list[SchemafilescanningFileSecurityReport]',
        'repo_metadata': 'SchemafilescanningRepoMetadata',
        'unscanned_file_paths': 'list[str]',
        'severity': 'RimeSeverity'
    }

    attribute_map = {
        'file_scan_id': 'fileScanId',
        'project_id': 'projectId',
        'model_id': 'modelId',
        'rime_agent_version': 'rimeAgentVersion',
        'upload_time': 'uploadTime',
        'file_security_reports': 'fileSecurityReports',
        'repo_metadata': 'repoMetadata',
        'unscanned_file_paths': 'unscannedFilePaths',
        'severity': 'severity'
    }

    def __init__(self, file_scan_id=None, project_id=None, model_id=None, rime_agent_version=None, upload_time=None, file_security_reports=None, repo_metadata=None, unscanned_file_paths=None, severity=None):  # noqa: E501
        """SchemafilescanningFileScanResult - a model defined in Swagger"""  # noqa: E501
        self._file_scan_id = None
        self._project_id = None
        self._model_id = None
        self._rime_agent_version = None
        self._upload_time = None
        self._file_security_reports = None
        self._repo_metadata = None
        self._unscanned_file_paths = None
        self._severity = None
        self.discriminator = None
        if file_scan_id is not None:
            self.file_scan_id = file_scan_id
        if project_id is not None:
            self.project_id = project_id
        if model_id is not None:
            self.model_id = model_id
        if rime_agent_version is not None:
            self.rime_agent_version = rime_agent_version
        if upload_time is not None:
            self.upload_time = upload_time
        if file_security_reports is not None:
            self.file_security_reports = file_security_reports
        if repo_metadata is not None:
            self.repo_metadata = repo_metadata
        if unscanned_file_paths is not None:
            self.unscanned_file_paths = unscanned_file_paths
        if severity is not None:
            self.severity = severity

    @property
    def file_scan_id(self):
        """Gets the file_scan_id of this SchemafilescanningFileScanResult.  # noqa: E501


        :return: The file_scan_id of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._file_scan_id

    @file_scan_id.setter
    def file_scan_id(self, file_scan_id):
        """Sets the file_scan_id of this SchemafilescanningFileScanResult.


        :param file_scan_id: The file_scan_id of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: RimeUUID
        """

        self._file_scan_id = file_scan_id

    @property
    def project_id(self):
        """Gets the project_id of this SchemafilescanningFileScanResult.  # noqa: E501


        :return: The project_id of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this SchemafilescanningFileScanResult.


        :param project_id: The project_id of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: RimeUUID
        """

        self._project_id = project_id

    @property
    def model_id(self):
        """Gets the model_id of this SchemafilescanningFileScanResult.  # noqa: E501


        :return: The model_id of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this SchemafilescanningFileScanResult.


        :param model_id: The model_id of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: RimeUUID
        """

        self._model_id = model_id

    @property
    def rime_agent_version(self):
        """Gets the rime_agent_version of this SchemafilescanningFileScanResult.  # noqa: E501

        The version of the RIME agent that was used to scan the model.  # noqa: E501

        :return: The rime_agent_version of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: str
        """
        return self._rime_agent_version

    @rime_agent_version.setter
    def rime_agent_version(self, rime_agent_version):
        """Sets the rime_agent_version of this SchemafilescanningFileScanResult.

        The version of the RIME agent that was used to scan the model.  # noqa: E501

        :param rime_agent_version: The rime_agent_version of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: str
        """

        self._rime_agent_version = rime_agent_version

    @property
    def upload_time(self):
        """Gets the upload_time of this SchemafilescanningFileScanResult.  # noqa: E501

        The time when the file scan result was uploaded.  # noqa: E501

        :return: The upload_time of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: datetime
        """
        return self._upload_time

    @upload_time.setter
    def upload_time(self, upload_time):
        """Sets the upload_time of this SchemafilescanningFileScanResult.

        The time when the file scan result was uploaded.  # noqa: E501

        :param upload_time: The upload_time of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: datetime
        """

        self._upload_time = upload_time

    @property
    def file_security_reports(self):
        """Gets the file_security_reports of this SchemafilescanningFileScanResult.  # noqa: E501

        The security reports for the files that were scanned.  # noqa: E501

        :return: The file_security_reports of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: list[SchemafilescanningFileSecurityReport]
        """
        return self._file_security_reports

    @file_security_reports.setter
    def file_security_reports(self, file_security_reports):
        """Sets the file_security_reports of this SchemafilescanningFileScanResult.

        The security reports for the files that were scanned.  # noqa: E501

        :param file_security_reports: The file_security_reports of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: list[SchemafilescanningFileSecurityReport]
        """

        self._file_security_reports = file_security_reports

    @property
    def repo_metadata(self):
        """Gets the repo_metadata of this SchemafilescanningFileScanResult.  # noqa: E501


        :return: The repo_metadata of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: SchemafilescanningRepoMetadata
        """
        return self._repo_metadata

    @repo_metadata.setter
    def repo_metadata(self, repo_metadata):
        """Sets the repo_metadata of this SchemafilescanningFileScanResult.


        :param repo_metadata: The repo_metadata of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: SchemafilescanningRepoMetadata
        """

        self._repo_metadata = repo_metadata

    @property
    def unscanned_file_paths(self):
        """Gets the unscanned_file_paths of this SchemafilescanningFileScanResult.  # noqa: E501

        The list of files that were not scanned.  # noqa: E501

        :return: The unscanned_file_paths of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._unscanned_file_paths

    @unscanned_file_paths.setter
    def unscanned_file_paths(self, unscanned_file_paths):
        """Sets the unscanned_file_paths of this SchemafilescanningFileScanResult.

        The list of files that were not scanned.  # noqa: E501

        :param unscanned_file_paths: The unscanned_file_paths of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: list[str]
        """

        self._unscanned_file_paths = unscanned_file_paths

    @property
    def severity(self):
        """Gets the severity of this SchemafilescanningFileScanResult.  # noqa: E501


        :return: The severity of this SchemafilescanningFileScanResult.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this SchemafilescanningFileScanResult.


        :param severity: The severity of this SchemafilescanningFileScanResult.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchemafilescanningFileScanResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchemafilescanningFileScanResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SchemafilescanningRepoMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'purl': 'FilescanningPackageURL',
        'repo_last_modified_time': 'datetime',
        'tags': 'list[str]',
        'reputation': 'SchemafilescanningRepoMetadataReputation',
        'license': 'SchemafilescanningRepoMetadataLicense',
        'author': 'str'
    }

    attribute_map = {
        'purl': 'purl',
        'repo_last_modified_time': 'repoLastModifiedTime',
        'tags': 'tags',
        'reputation': 'reputation',
        'license': 'license',
        'author': 'author'
    }

    def __init__(self, purl=None, repo_last_modified_time=None, tags=None, reputation=None, license=None, author=None):  # noqa: E501
        """SchemafilescanningRepoMetadata - a model defined in Swagger"""  # noqa: E501
        self._purl = None
        self._repo_last_modified_time = None
        self._tags = None
        self._reputation = None
        self._license = None
        self._author = None
        self.discriminator = None
        if purl is not None:
            self.purl = purl
        if repo_last_modified_time is not None:
            self.repo_last_modified_time = repo_last_modified_time
        if tags is not None:
            self.tags = tags
        if reputation is not None:
            self.reputation = reputation
        if license is not None:
            self.license = license
        if author is not None:
            self.author = author

    @property
    def purl(self):
        """Gets the purl of this SchemafilescanningRepoMetadata.  # noqa: E501


        :return: The purl of this SchemafilescanningRepoMetadata.  # noqa: E501
        :rtype: FilescanningPackageURL
        """
        return self._purl

    @purl.setter
    def purl(self, purl):
        """Sets the purl of this SchemafilescanningRepoMetadata.


        :param purl: The purl of this SchemafilescanningRepoMetadata.  # noqa: E501
        :type: FilescanningPackageURL
        """

        self._purl = purl

    @property
    def repo_last_modified_time(self):
        """Gets the repo_last_modified_time of this SchemafilescanningRepoMetadata.  # noqa: E501

        The time when the model repository was last modified, inferred from the git history.  # noqa: E501

        :return: The repo_last_modified_time of this SchemafilescanningRepoMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._repo_last_modified_time

    @repo_last_modified_time.setter
    def repo_last_modified_time(self, repo_last_modified_time):
        """Sets the repo_last_modified_time of this SchemafilescanningRepoMetadata.

        The time when the model repository was last modified, inferred from the git history.  # noqa: E501

        :param repo_last_modified_time: The repo_last_modified_time of this SchemafilescanningRepoMetadata.  # noqa: E501
        :type: datetime
        """

        self._repo_last_modified_time = repo_last_modified_time

    @property
    def tags(self):
        """Gets the tags of this SchemafilescanningRepoMetadata.  # noqa: E501

        The tags associated with the model repository.  # noqa: E501

        :return: The tags of this SchemafilescanningRepoMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this SchemafilescanningRepoMetadata.

        The tags associated with the model repository.  # noqa: E501

        :param tags: The tags of this SchemafilescanningRepoMetadata.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def reputation(self):
        """Gets the reputation of this SchemafilescanningRepoMetadata.  # noqa: E501


        :return: The reputation of this SchemafilescanningRepoMetadata.  # noqa: E501
        :rtype: SchemafilescanningRepoMetadataReputation
        """
        return self._reputation

    @reputation.setter
    def reputation(self, reputation):
        """Sets the reputation of this SchemafilescanningRepoMetadata.


        :param reputation: The reputation of this SchemafilescanningRepoMetadata.  # noqa: E501
        :type: SchemafilescanningRepoMetadataReputation
        """

        self._reputation = reputation

    @property
    def license(self):
        """Gets the license of this SchemafilescanningRepoMetadata.  # noqa: E501


        :return: The license of this SchemafilescanningRepoMetadata.  # noqa: E501
        :rtype: SchemafilescanningRepoMetadataLicense
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this SchemafilescanningRepoMetadata.


        :param license: The license of this SchemafilescanningRepoMetadata.  # noqa: E501
        :type: SchemafilescanningRepoMetadataLicense
        """

        self._license = license

    @property
    def author(self):
        """Gets the author of this SchemafilescanningRepoMetadata.  # noqa: E501


        :return: The author of this SchemafilescanningRepoMetadata.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this SchemafilescanningRepoMetadata.


        :param author: The author of this SchemafilescanningRepoMetadata.  # noqa: E501
        :type: str
        """

        self._author = author

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchemafilescanningRepoMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchemafilescanningRepoMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FirewallInstanceIdUuidValidateBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_input_text': 'str',
        'contexts': 'list[str]',
        'output_text': 'str',
        'firewall_instance_id': 'object'
    }

    attribute_map = {
        'user_input_text': 'userInputText',
        'contexts': 'contexts',
        'output_text': 'outputText',
        'firewall_instance_id': 'firewallInstanceId'
    }

    def __init__(self, user_input_text=None, contexts=None, output_text=None, firewall_instance_id=None):  # noqa: E501
        """FirewallInstanceIdUuidValidateBody - a model defined in Swagger"""  # noqa: E501
        self._user_input_text = None
        self._contexts = None
        self._output_text = None
        self._firewall_instance_id = None
        self.discriminator = None
        if user_input_text is not None:
            self.user_input_text = user_input_text
        if contexts is not None:
            self.contexts = contexts
        if output_text is not None:
            self.output_text = output_text
        if firewall_instance_id is not None:
            self.firewall_instance_id = firewall_instance_id

    @property
    def user_input_text(self):
        """Gets the user_input_text of this FirewallInstanceIdUuidValidateBody.  # noqa: E501

        Input text is the raw user input. The generative firewall performs validation on input to prevent risk configured by firewall rules.  # noqa: E501

        :return: The user_input_text of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :rtype: str
        """
        return self._user_input_text

    @user_input_text.setter
    def user_input_text(self, user_input_text):
        """Sets the user_input_text of this FirewallInstanceIdUuidValidateBody.

        Input text is the raw user input. The generative firewall performs validation on input to prevent risk configured by firewall rules.  # noqa: E501

        :param user_input_text: The user_input_text of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :type: str
        """

        self._user_input_text = user_input_text

    @property
    def contexts(self):
        """Gets the contexts of this FirewallInstanceIdUuidValidateBody.  # noqa: E501

        Documents that represent relevant context for the input query that is fed into the model. e.g. in a RAG application this will be the documents loaded during the RAG Retrieval phase to augment the LLM's response.  # noqa: E501

        :return: The contexts of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._contexts

    @contexts.setter
    def contexts(self, contexts):
        """Sets the contexts of this FirewallInstanceIdUuidValidateBody.

        Documents that represent relevant context for the input query that is fed into the model. e.g. in a RAG application this will be the documents loaded during the RAG Retrieval phase to augment the LLM's response.  # noqa: E501

        :param contexts: The contexts of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :type: list[str]
        """

        self._contexts = contexts

    @property
    def output_text(self):
        """Gets the output_text of this FirewallInstanceIdUuidValidateBody.  # noqa: E501

        Output text is the raw output text of the model. The generative firewall performs validation on the output so the system can determine whether to show it to users.  # noqa: E501

        :return: The output_text of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :rtype: str
        """
        return self._output_text

    @output_text.setter
    def output_text(self, output_text):
        """Sets the output_text of this FirewallInstanceIdUuidValidateBody.

        Output text is the raw output text of the model. The generative firewall performs validation on the output so the system can determine whether to show it to users.  # noqa: E501

        :param output_text: The output_text of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :type: str
        """

        self._output_text = output_text

    @property
    def firewall_instance_id(self):
        """Gets the firewall_instance_id of this FirewallInstanceIdUuidValidateBody.  # noqa: E501

        Unique ID of an object in RIME.  # noqa: E501

        :return: The firewall_instance_id of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :rtype: object
        """
        return self._firewall_instance_id

    @firewall_instance_id.setter
    def firewall_instance_id(self, firewall_instance_id):
        """Sets the firewall_instance_id of this FirewallInstanceIdUuidValidateBody.

        Unique ID of an object in RIME.  # noqa: E501

        :param firewall_instance_id: The firewall_instance_id of this FirewallInstanceIdUuidValidateBody.  # noqa: E501
        :type: object
        """

        self._firewall_instance_id = firewall_instance_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FirewallInstanceIdUuidValidateBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallInstanceIdUuidValidateBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeDetailedUpgradeStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'RimeUpgradeStatus',
        'last_update_time': 'datetime',
        'error_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'last_update_time': 'lastUpdateTime',
        'error_message': 'errorMessage'
    }

    def __init__(self, status=None, last_update_time=None, error_message=None):  # noqa: E501
        """RimeDetailedUpgradeStatus - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._last_update_time = None
        self._error_message = None
        self.discriminator = None
        if status is not None:
            self.status = status
        self.last_update_time = last_update_time
        if error_message is not None:
            self.error_message = error_message

    @property
    def status(self):
        """Gets the status of this RimeDetailedUpgradeStatus.  # noqa: E501


        :return: The status of this RimeDetailedUpgradeStatus.  # noqa: E501
        :rtype: RimeUpgradeStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RimeDetailedUpgradeStatus.


        :param status: The status of this RimeDetailedUpgradeStatus.  # noqa: E501
        :type: RimeUpgradeStatus
        """

        self._status = status

    @property
    def last_update_time(self):
        """Gets the last_update_time of this RimeDetailedUpgradeStatus.  # noqa: E501


        :return: The last_update_time of this RimeDetailedUpgradeStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this RimeDetailedUpgradeStatus.


        :param last_update_time: The last_update_time of this RimeDetailedUpgradeStatus.  # noqa: E501
        :type: datetime
        """
        if last_update_time is None:
            raise ValueError("Invalid value for `last_update_time`, must not be `None`")  # noqa: E501

        self._last_update_time = last_update_time

    @property
    def error_message(self):
        """Gets the error_message of this RimeDetailedUpgradeStatus.  # noqa: E501

        The error message if the status is failed.  # noqa: E501

        :return: The error_message of this RimeDetailedUpgradeStatus.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this RimeDetailedUpgradeStatus.

        The error message if the status is failed.  # noqa: E501

        :param error_message: The error_message of this RimeDetailedUpgradeStatus.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeDetailedUpgradeStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeDetailedUpgradeStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetUpgradeForAgentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'desired_state': 'RimeAgentDesiredState',
        'rendered_manifests': 'list[str]'
    }

    attribute_map = {
        'desired_state': 'desiredState',
        'rendered_manifests': 'renderedManifests'
    }

    def __init__(self, desired_state=None, rendered_manifests=None):  # noqa: E501
        """RimeGetUpgradeForAgentResponse - a model defined in Swagger"""  # noqa: E501
        self._desired_state = None
        self._rendered_manifests = None
        self.discriminator = None
        if desired_state is not None:
            self.desired_state = desired_state
        if rendered_manifests is not None:
            self.rendered_manifests = rendered_manifests

    @property
    def desired_state(self):
        """Gets the desired_state of this RimeGetUpgradeForAgentResponse.  # noqa: E501


        :return: The desired_state of this RimeGetUpgradeForAgentResponse.  # noqa: E501
        :rtype: RimeAgentDesiredState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state):
        """Sets the desired_state of this RimeGetUpgradeForAgentResponse.


        :param desired_state: The desired_state of this RimeGetUpgradeForAgentResponse.  # noqa: E501
        :type: RimeAgentDesiredState
        """

        self._desired_state = desired_state

    @property
    def rendered_manifests(self):
        """Gets the rendered_manifests of this RimeGetUpgradeForAgentResponse.  # noqa: E501

        The rendered Kubernetes manifests for the agent, in stringified form. These are based on the desired state of the agent.  The DP does not have access to the helm chart, so these must be rendered by the AgentManager in the CP.  # noqa: E501

        :return: The rendered_manifests of this RimeGetUpgradeForAgentResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._rendered_manifests

    @rendered_manifests.setter
    def rendered_manifests(self, rendered_manifests):
        """Sets the rendered_manifests of this RimeGetUpgradeForAgentResponse.

        The rendered Kubernetes manifests for the agent, in stringified form. These are based on the desired state of the agent.  The DP does not have access to the helm chart, so these must be rendered by the AgentManager in the CP.  # noqa: E501

        :param rendered_manifests: The rendered_manifests of this RimeGetUpgradeForAgentResponse.  # noqa: E501
        :type: list[str]
        """

        self._rendered_manifests = rendered_manifests

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetUpgradeForAgentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetUpgradeForAgentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ListTestCasesRequestListTestCasesQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_run_id': 'str',
        'test_types': 'list[str]',
        'url_safe_feature_ids': 'list[str]'
    }

    attribute_map = {
        'test_run_id': 'testRunId',
        'test_types': 'testTypes',
        'url_safe_feature_ids': 'urlSafeFeatureIds'
    }

    def __init__(self, test_run_id=None, test_types=None, url_safe_feature_ids=None):  # noqa: E501
        """ListTestCasesRequestListTestCasesQuery - a model defined in Swagger"""  # noqa: E501
        self._test_run_id = None
        self._test_types = None
        self._url_safe_feature_ids = None
        self.discriminator = None
        if test_run_id is not None:
            self.test_run_id = test_run_id
        if test_types is not None:
            self.test_types = test_types
        if url_safe_feature_ids is not None:
            self.url_safe_feature_ids = url_safe_feature_ids

    @property
    def test_run_id(self):
        """Gets the test_run_id of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501

        Uniquely specifies a Test Run associated with test cases. Specify exactly one of the page_token field or this field.  # noqa: E501

        :return: The test_run_id of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501
        :rtype: str
        """
        return self._test_run_id

    @test_run_id.setter
    def test_run_id(self, test_run_id):
        """Sets the test_run_id of this ListTestCasesRequestListTestCasesQuery.

        Uniquely specifies a Test Run associated with test cases. Specify exactly one of the page_token field or this field.  # noqa: E501

        :param test_run_id: The test_run_id of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501
        :type: str
        """

        self._test_run_id = test_run_id

    @property
    def test_types(self):
        """Gets the test_types of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501

        Optional filter for test types.  # noqa: E501

        :return: The test_types of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._test_types

    @test_types.setter
    def test_types(self, test_types):
        """Sets the test_types of this ListTestCasesRequestListTestCasesQuery.

        Optional filter for test types.  # noqa: E501

        :param test_types: The test_types of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501
        :type: list[str]
        """

        self._test_types = test_types

    @property
    def url_safe_feature_ids(self):
        """Gets the url_safe_feature_ids of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501

        Optional filter for features.  # noqa: E501

        :return: The url_safe_feature_ids of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._url_safe_feature_ids

    @url_safe_feature_ids.setter
    def url_safe_feature_ids(self, url_safe_feature_ids):
        """Sets the url_safe_feature_ids of this ListTestCasesRequestListTestCasesQuery.

        Optional filter for features.  # noqa: E501

        :param url_safe_feature_ids: The url_safe_feature_ids of this ListTestCasesRequestListTestCasesQuery.  # noqa: E501
        :type: list[str]
        """

        self._url_safe_feature_ids = url_safe_feature_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListTestCasesRequestListTestCasesQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTestCasesRequestListTestCasesQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeListWorkspacesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workspaces': 'list[RimeWorkspace]',
        'next_page_token': 'str',
        'has_more': 'bool'
    }

    attribute_map = {
        'workspaces': 'workspaces',
        'next_page_token': 'nextPageToken',
        'has_more': 'hasMore'
    }

    def __init__(self, workspaces=None, next_page_token=None, has_more=None):  # noqa: E501
        """RimeListWorkspacesResponse - a model defined in Swagger"""  # noqa: E501
        self._workspaces = None
        self._next_page_token = None
        self._has_more = None
        self.discriminator = None
        if workspaces is not None:
            self.workspaces = workspaces
        if next_page_token is not None:
            self.next_page_token = next_page_token
        if has_more is not None:
            self.has_more = has_more

    @property
    def workspaces(self):
        """Gets the workspaces of this RimeListWorkspacesResponse.  # noqa: E501


        :return: The workspaces of this RimeListWorkspacesResponse.  # noqa: E501
        :rtype: list[RimeWorkspace]
        """
        return self._workspaces

    @workspaces.setter
    def workspaces(self, workspaces):
        """Sets the workspaces of this RimeListWorkspacesResponse.


        :param workspaces: The workspaces of this RimeListWorkspacesResponse.  # noqa: E501
        :type: list[RimeWorkspace]
        """

        self._workspaces = workspaces

    @property
    def next_page_token(self):
        """Gets the next_page_token of this RimeListWorkspacesResponse.  # noqa: E501


        :return: The next_page_token of this RimeListWorkspacesResponse.  # noqa: E501
        :rtype: str
        """
        return self._next_page_token

    @next_page_token.setter
    def next_page_token(self, next_page_token):
        """Sets the next_page_token of this RimeListWorkspacesResponse.


        :param next_page_token: The next_page_token of this RimeListWorkspacesResponse.  # noqa: E501
        :type: str
        """

        self._next_page_token = next_page_token

    @property
    def has_more(self):
        """Gets the has_more of this RimeListWorkspacesResponse.  # noqa: E501


        :return: The has_more of this RimeListWorkspacesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_more

    @has_more.setter
    def has_more(self, has_more):
        """Sets the has_more of this RimeListWorkspacesResponse.


        :param has_more: The has_more of this RimeListWorkspacesResponse.  # noqa: E501
        :type: bool
        """

        self._has_more = has_more

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeListWorkspacesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeListWorkspacesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
